==> pycatia-0.3.3.tar.gz: pycatia-0.3.3/pycatia/part_interfaces/mirror.py <==
#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.part_interfaces.transformation_shape import TransformationShape
from pycatia.system_interfaces.any_object import AnyObject


class Mirror(TransformationShape):

    """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.TransformationShape
                |                             Mirror
                | 
                | Represents the mirror shape.
                | It duplicates a shape with respect to a planar mirroring element, such as a
                | planar face or a plane.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.mirror = com_object

    @property
    def mirroring_object(self):
        """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property MirroringObject() As AnyObject (Read Only)
                | 
                |     Returns the mirroring Object.

        :return: AnyObject
        """

        return AnyObject(self.mirror.MirroringObject)

    @property
    def mirroring_plane(self):
        """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property MirroringPlane() As Reference
                | 
                |     Returns or sets the mirroring reference plane. It can be a plane, or a
                |     plane face.
                |     To set the property, you can use the following Boundary object:
                |     PlanarFace.
                | 
                |     Example:
                |         The following example returns in ref the mirroring reference plane of
                |         the mirroring firstMirroring, and then sets it to the created
                |         MyRef:
                | 
                |          Set ref = firstMirroring.MirroringPlane
                |          Set MyRef = part.CreateReferenceFromGeometry (plane)
                |          firstMirroring.MirroringPlane = MyRef

        :return: Reference
        """

        return Reference(self.mirror.MirroringPlane)

    @mirroring_plane.setter
    def mirroring_plane(self, value):
        """
        :param Reference value:
        """

        self.mirror.MirroringPlane = value

    def __repr__(self):
        return f'Mirror(name="{ self.name }")'

==> pycatia-0.3.8.tar.gz: pycatia-0.3.8/pycatia/part_interfaces/mirror.py <==
#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.part_interfaces.transformation_shape import TransformationShape
from pycatia.system_interfaces.any_object import AnyObject


class Mirror(TransformationShape):

    """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.TransformationShape
                |                             Mirror
                | 
                | Represents the mirror shape.
                | It duplicates a shape with respect to a planar mirroring element, such as a
                | planar face or a plane.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.mirror = com_object

    @property
    def mirroring_object(self) -> AnyObject:
        """
        .. note::
            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MirroringObject() As AnyObject (Read Only)
                | 
                |     Returns the mirroring Object.

        :return: AnyObject
        :rtype: AnyObject
        """

        return AnyObject(self.mirror.MirroringObject)

    @property
    def mirroring_plane(self) -> Reference:
        """
        .. note::
            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MirroringPlane() As Reference
                | 
                |     Returns or sets the mirroring reference plane. It can be a plane, or a
                |     plane face.
                |     To set the property, you can use the following Boundary object:
                |     PlanarFace.
                | 
                |     Example:
                |         The following example returns in ref the mirroring reference plane of
                |         the mirroring firstMirroring, and then sets it to the created
                |         MyRef:
                | 
                |          Set ref = firstMirroring.MirroringPlane
                |          Set MyRef = part.CreateReferenceFromGeometry (plane)
                |          firstMirroring.MirroringPlane = MyRef

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.mirror.MirroringPlane)

    @mirroring_plane.setter
    def mirroring_plane(self, value: Reference):
        """
        :param Reference value:
        """

        self.mirror.MirroringPlane = value

    def __repr__(self):
        return f'Mirror(name="{ self.name }")'
